package com.sh.centerServer.center;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.sh.commons.tuple.Tuple;
import com.sh.commons.tuple.TwoTuple;
import com.sh.game.system.player.RoleManager;
import java.util.HashMap;
import java.util.Map;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/* loaded from: Group.class */
public class Group {
    private static final Logger log = LoggerFactory.getLogger(Group.class);
    private long groupId;
    private long gameId;
    private int mapServerId;
    private int index;
    private int mapId;
    private long startTime;
    private int serverId;
    private Map<Long, Player> players = new HashMap();
    private long halfFullTime = 0;
    private long matchEndTime = 0;
    private long gameEndTime = 0;
    private boolean multiPlayer = false;

    public void setGroupId(long groupId) {
        this.groupId = groupId;
    }

    public void setGameId(long gameId) {
        this.gameId = gameId;
    }

    public void setPlayers(Map<Long, Player> players) {
        this.players = players;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public void setMapId(int mapId) {
        this.mapId = mapId;
    }

    public void setStartTime(long startTime) {
        this.startTime = startTime;
    }

    public void setHalfFullTime(long halfFullTime) {
        this.halfFullTime = halfFullTime;
    }

    public void setMatchEndTime(long matchEndTime) {
        this.matchEndTime = matchEndTime;
    }

    public void setGameEndTime(long gameEndTime) {
        this.gameEndTime = gameEndTime;
    }

    public void setServerId(int serverId) {
        this.serverId = serverId;
    }

    public void setMultiPlayer(boolean multiPlayer) {
        this.multiPlayer = multiPlayer;
    }

    public long getGroupId() {
        return this.groupId;
    }

    public long getGameId() {
        return this.gameId;
    }

    public Map<Long, Player> getPlayers() {
        return this.players;
    }

    public int getMapServerId() {
        return this.mapServerId;
    }

    public int getIndex() {
        return this.index;
    }

    public int getMapId() {
        return this.mapId;
    }

    public long getStartTime() {
        return this.startTime;
    }

    public long getHalfFullTime() {
        return this.halfFullTime;
    }

    public long getMatchEndTime() {
        return this.matchEndTime;
    }

    public long getGameEndTime() {
        return this.gameEndTime;
    }

    public int getServerId() {
        return this.serverId;
    }

    public int size() {
        return this.players.size();
    }

    public Group(long startTime) {
        this.startTime = startTime;
    }

    public boolean isFull() {
        return this.players.size() >= getFull();
    }

    public boolean isMultiPlayer() {
        return this.multiPlayer;
    }

    public void addPlayer(Player player) {
        this.players.put(Long.valueOf(player.getRoleId()), player);
        player.setGroupId(this.groupId);
    }

    public void setMapServerId(int mapServerId) {
        this.mapServerId = mapServerId;
        for (Player player : this.players.values()) {
            player.setCurMapServerId(mapServerId);
        }
    }

    public TwoTuple<Integer, Integer> getScore() {
        int i;
        int score = Integer.MIN_VALUE;
        int ratio = 0;
        for (Player player : this.players.values()) {
            if (player.getScore() > score) {
                score = player.getScore();
                int curWin = player.getCurWin();
                ratio = 0;
                if (curWin != 0) {
                    for (int i2 = 0; i2 < 5; i2++) {
                        boolean win = ((curWin >> i2) & 1) != 0;
                        if (i2 == 0) {
                            i = win ? 1 : -1;
                        } else if ((!win || ratio >= 0) && (win || ratio <= 0)) {
                            i = ratio + (win ? 1 : -1);
                        }
                        ratio = i;
                    }
                }
            }
        }
        return Tuple.tuple(Integer.valueOf(score), Integer.valueOf(ratio));
    }

    public int getNbValue() {
        int nbValue = 0;
        for (Player player : this.players.values()) {
            if (player.getNbValue() > nbValue) {
                nbValue = player.getNbValue();
            }
        }
        return nbValue;
    }

    public TwoTuple<Integer, Integer> getMatchValue(long now) {
        int ratio;
        int turn = getTurn(now);
        int nbValue = getNbValue();
        if (turn > 10) {
            ratio = turn - 10;
        } else {
            ratio = Math.min(nbValue >= 35000 ? 3 : 4, (turn + 1) / 2);
        }
        int changeValue = (nbValue * ratio) / 10;
        return Tuple.tuple(Integer.valueOf(Math.max(nbValue - changeValue, 0)), Integer.valueOf(nbValue + changeValue));
    }

    public boolean isNBValueSuit(Group group) {
        double diff = group.getNbValue() / getNbValue();
        return diff >= 0.9d && diff <= 1.1d;
    }

    public boolean checkCanMerge(Group group) {
        return group != null && this.mapId == group.mapId && this.players.size() + group.players.size() <= getFull();
    }

    public boolean checkCanMergeSingle(Group group) {
        return group != null && this.mapId == group.mapId && this.players.size() + group.players.size() <= getFull() * 2 && this.players.size() == 1 && group.players.size() == 1;
    }

    private int getFull() {
        return this.mapId == 1010 ? CenterManager.GROUP_SIZE_3V3 : this.mapId == 1006 ? CenterManager.GROUP_SIZE_5V5 : RoleManager.getSLDGSundryConfigEffect(48, 0, 100);
    }

    public void merge(Group group) {
        this.multiPlayer = group.isMultiPlayer() || this.multiPlayer;
        for (Player player : group.players.values()) {
            addPlayer(player);
        }
        this.startTime = Math.min(this.startTime, group.startTime);
        if (this.halfFullTime != 0 && group.halfFullTime != 0) {
            this.halfFullTime = Math.min(this.halfFullTime, group.halfFullTime);
        } else {
            this.halfFullTime = Math.max(this.halfFullTime, group.halfFullTime);
        }
        group.players.clear();
    }

    public int getTurn(long now) {
        return (int) (((now - this.startTime) / 5000) + 1);
    }

    public String toString() {
        return "Group{groupId=" + this.groupId + ", gameId=" + this.gameId + ", mapServerId=" + this.mapServerId + ", mapId=" + this.mapId + '}';
    }

    public JSONObject toResultString() {
        JSONObject result = new JSONObject();
        result.put("gameId", Long.valueOf(this.gameId));
        result.put("mapServerId", Integer.valueOf(this.mapServerId));
        result.put("mapId", Integer.valueOf(this.mapId));
        result.put("matchEndTime", Long.valueOf(this.matchEndTime));
        result.put("gameEndTime", Long.valueOf(this.gameEndTime));
        return result;
    }

    public JSONObject toGroupString() {
        JSONObject result = new JSONObject();
        result.put("groupId", Long.valueOf(this.groupId));
        result.put("startTime", Long.valueOf(this.startTime));
        JSONArray array = new JSONArray();
        for (Player player : this.players.values()) {
            JSONObject playerResult = new JSONObject();
            playerResult.put("roleId", Long.valueOf(player.getRoleId()));
            playerResult.put("startTime", Long.valueOf(player.getStartTime()));
            playerResult.put("serverId", Integer.valueOf(player.getServerId()));
            playerResult.put("nbValue", Integer.valueOf(player.getNbValue()));
            playerResult.put("teamId", Long.valueOf(player.getTeamId()));
            playerResult.put("score", Integer.valueOf(player.getScore()));
            array.add(playerResult);
        }
        result.put("playerResults", array);
        result.put("groupId", Long.valueOf(this.groupId));
        return result;
    }
}
